@@ -1,4 +1,4 @@
-#   This file is part of Python Builder
+#   This file is part of PyBuilder
 #
 #   Copyright 2011-2013 PyBuilder Team
 #
@@ -25,7 +25,7 @@ import unittest
 from pybuilder.core import init, task, description, use_plugin
 from pybuilder.errors import BuildFailedException
 from pybuilder.utils import discover_modules, render_report
-from pybuilder.terminal import write_line
+from pybuilder.terminal import print_text_line
 use_plugin("python.core")
 
 
@@ -89,15 +89,15 @@ def write_report(name, project, logger, result, console_out):
                                  "traceback": error[1]})
         logger.error("Test has error: %s", error[0].id())
 
-        if project.verbose:
-            write_line(error[1])
+        if project.get_property("verbose"):
+            print_text_line(error[1])
 
     for failure in result.failures:
         report["failures"].append({"test": failure[0].id(),
                                    "traceback": failure[1]})
         logger.error("Test failed: %s", failure[0].id())
 
-        if project.verbose:
-            write_line(failure[1])
+        if project.get_property("verbose"):
+            print_text_line(failure[1])
 
     project.write_report("%s.json" % name, render_report(report))
